@@ -5,7 +5,7 @@
 See ``dir(unpythonic)`` and submodule docstrings for more.
 """
 
-__version__ = '0.5.0'
+__version__ = '0.5.1'
 
 from . import rc
 
@@ -27,7 +27,12 @@ from .misc import *
 # We manually emulate:
 #   - making the submodule visible like __init__.py usually does
 #   - from submod import *
-#
+
+def _starimport(module):  # same effect as "from module import *"
+    g = globals()
+    for name in module.__all__:
+        g[name] = getattr(module, name)
+
 def _init_tco():
     global tco
     if rc._tco_impl == "exc":
@@ -36,32 +41,28 @@ def _init_tco():
         from . import fasttco as tco
     else:
         raise ValueError("Unknown TCO implementation '{}'".format(rc._tco_impl))
-    g = globals()
-    for name in tco.__all__:
-        g[name] = getattr(tco, name)
+    _starimport(tco)
 
 def _init_fploop(reload=False):
     global fploop
     from . import fploop
     # We must reload fploop, because its module-level initialization
-    # performs some imports from the TCO module.
+    # performs some from-imports from the TCO module.
     if reload:
         from importlib import reload
         fploop = reload(fploop)
-    g = globals()
-    for name in fploop.__all__:
-        g[name] = getattr(fploop, name)
+    _starimport(fploop)
 
 _init_tco()
 _init_fploop()
 
-def enable_fasttco():
-    """Switch to the fast TCO implementation.
+def enable_fasttco(b=True):
+    """Switch the fast TCO implementation on/off.
 
     It is 2-5x faster, but pickier about its syntax, hence not the default.
     See ``unpythonic.fasttco`` for details.
     """
-    rc._tco_impl = "fast"
+    rc._tco_impl = "fast" if b else "exc"
 
     _init_tco()
     _init_fploop(reload=True)
